@@ -76,6 +76,10 @@ def add_license(session, short_title, title, **kwargs):
     kwargs['short_title'] = short_title
     kwargs['title'] = title
 
+    # check if either full text or link is given
+    if 'full_text' not in kwargs and 'link' not in kwargs:
+        raise AttributeError('Either full_text or a link to the license full text has to be given')
+
     # add the license
     return add_record(session=session, tablename='licenses', **kwargs)
 
@@ -153,7 +157,7 @@ def add_variable(session, name, symbol, unit):
     return add_record(session=session, tablename='variables', **attrs)
 
 
-def add_keyword(session, path):
+def add_keyword(session, path, thesaurus):
     r"""Add Keyword
 
     Add a new keyword to the database. The keyword is
@@ -167,6 +171,23 @@ def add_keyword(session, path):
         A full path to the keyword, each element connected
         by a ' > ' sequence. E.g.: 
         Topic > Term > Variable_level_1 etc.
+    thesaurus : dict, int
+        .. versionadded:: 0.1.10
+        Either a thesaurus entity, that distributes the 
+        controlled keywords, or an id of the an already 
+        existing thesaurusName. It is highly recommended
+        to use an existing ID.
+
+    Note
+    ----
+    This API endpoint is designed to add custom keywords to 
+    metacatalog. It will use the full path keywords and split 
+    them automatically for convenience. 
+    .. warning::
+        Each keyword part will receive a **new** UUID, thus you 
+        have to use the `metacatalog.models.Keyword` interface 
+        to add **existing** keywords, that already contain a 
+        UUID.
 
     Returns
     -------
@@ -178,12 +199,18 @@ def add_keyword(session, path):
     current_parent_id = None
     keywords = []
 
+    if isinstance(thesaurus, int):
+        thesaurus_id = thesaurus
+    elif isinstance(thesaurus, dict):
+        thesaurus_ = add_record(session=session, tablename='thesaurus', **thesaurus)
+        thesaurus_id = thesaurus_.id
+
     # add each level, if it does not exist
     for i, level in enumerate(levels):
         # does the level exist?
         current = session.query(models.Keyword).filter(models.Keyword.value==level).filter(models.Keyword.parent_id==current_parent_id).first()
         if current is None:
-            attr = dict(parent_id=current_parent_id, value=level, uuid=uuid4(), path=' > '.join(levels[:i + 1]))
+            attr = dict(parent_id=current_parent_id, value=level, uuid=uuid4(), path=' > '.join(levels[:i + 1]), thesaurus_id=thesaurus_id)
             current = add_record(session=session, tablename='keywords', **attr)
         keywords.append(current)
         current_parent_id = current.id
@@ -192,7 +219,67 @@ def add_keyword(session, path):
     return keywords
 
 
-def add_person(session, first_name, last_name, affiliation=None):
+def add_thesaurus(session, name, title, organisation, url, description=None, uuid=None):
+    """
+    .. versionadded:: 0.1.10
+
+    Add a new thesaurus to reference new keywords.
+
+    .. warning::
+        If you want to add existing Thesaurii for reference, 
+        you **have to** to add their existing UUID as well,
+        otherwise this function will assign new ones.
+
+    Attributes
+    ----------
+   session : sqlalchemy.Session
+        SQLAlchemy session connected to the database.
+    uuid : str
+        An UUID version 4 to globally identify the keyword list.
+        If you add a new thesaurus, do not set the UUID as a new 
+        UUID will be set. 
+    name : str
+        Short name of the keyword list. Do not use the full 
+        qualified name here, just the short version used for 
+        filtering.
+    title : str
+        Full qualified name used by the distributor to identify 
+        the keyword list globally.
+    organisation : str
+        The full organisation name to identify the authority 
+        maintaining the thesaurus.
+    description : str
+        Optional. Futher details about the thesaurus, like scope or 
+        implementation details.
+    url : str
+        The permanent URL at which the full keyword list can be 
+        found. **Do not link the organisation or an overview page here**.
+        Usually, this points to an XML representation of the 
+        thesaurus. It may contain a placeholder called UUID to 
+        load specific keyword objects only.
+    
+    Returns
+    -------
+    thesaurus : metacatalog.models.Thesaurus
+        Thesaurus instance of the added thesaurus entity.
+
+    """
+    if uuid is None:
+        uuid = uuid4()
+    
+    attr = dict(
+        uuid=uuid,
+        name=name,
+        title=title,
+        organisation=organisation,
+        description=description,
+        url=url
+    )
+    
+    return add_record(session, tablename='thesaurus', **attr)
+
+
+def add_person(session, first_name, last_name, organisation_name=None, affiliation=None, attribution=None):
     r"""Add new Person
 
     Add a new Person to the database. A person can be a real Person
@@ -210,9 +297,16 @@ def add_person(session, first_name, last_name, affiliation=None):
     last_name : str
         A real persions last name. If first_name is NULL, 
         last_name is assumned to be an institution.
+    organisation_name : str
+        .. versionadded: 0.1.10
+        Optional, but **highly_recommended** if applicable. Name of
+        the head institution, whithout department.
     affiliation : str
         Affiliation if applicable. Has to go into a single string
-        of 1024 bytes.
+        of 1024 bytes. Full attribution including department and group name.
+    attribution : str.
+        Optional. Attribution recommondation for all datasets 
+        this Person is associated to as a first author.
     
     Returns
     -------
@@ -220,7 +314,13 @@ def add_person(session, first_name, last_name, affiliation=None):
         Entry instance of the added Person entity
   
     """
-    attr = dict(first_name=first_name, last_name=last_name, affiliation=affiliation)
+    attr = dict(
+        first_name=first_name, 
+        last_name=last_name,
+        organisation_name=organisation_name, 
+        affiliation=affiliation,
+        attribution=attribution
+    )
 
     return add_record(session=session, tablename='persons', **attr)
 
