@@ -72,9 +72,14 @@ def get_engine(*args, **kwargs):
     else:
         MISMATCH = False
 
+    # set an application name
+    kwargs.setdefault('connect_args', {'application_name': 'metacatalog_session'})
+
     # create a connection
     engine = create_engine(*args, **kwargs)
 
+    # need to rebuild this check by hand
+    """
     # check alembic version
     try:
         check_database_version(engine=engine)
@@ -84,7 +89,7 @@ def get_engine(*args, **kwargs):
             raise e
         elif MISMATCH == 'print':
             print(str(e))
-
+    """
     return engine
     
 
